======
Metron
======


Current analytics services supported:

* Google Analytics
* Mixpanel
* gaug.es
* Google AdWords Conversion Tracking


Documentation
-------------

Documentation can be found online at http://metron.readthedocs.org/


Commercial Support
------------------

This app, and many others like it, have been built in support of many of Eldarion's
own sites, and sites of our clients. We would love to help you on your next project
so get in touch by dropping us a note at info@eldarion.com.
